#!/usr/bin/env python

__author__ = 'boulefi'

import sys
import os

sys.path.append("../gui")
sys.path.append("../")

import unittest
import gui.matplotlibwidgetFile

class TestFormEvents(unittest.TestCase):
    def SetUp(self):
        """

        """
        test = 1


