# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui_Layout.ui'
#
# Created: Mon Jun  8 12:27:16 2015
#      by: PyQt4 UI code generator 4.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setEnabled(True)
        MainWindow.resize(1362, 958)
        MainWindow.setAnimated(True)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.run = QtGui.QPushButton(self.centralwidget)
        self.run.setGeometry(QtCore.QRect(19, 790, 101, 31))
        self.run.setObjectName(_fromUtf8("run"))
        self.tabWidget = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setGeometry(QtCore.QRect(0, 1, 1371, 781))
        self.tabWidget.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setItalic(False)
        font.setUnderline(False)
        self.tabWidget.setFont(font)
        self.tabWidget.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.tabWidget.setStyleSheet(_fromUtf8(""))
        self.tabWidget.setTabShape(QtGui.QTabWidget.Rounded)
        self.tabWidget.setElideMode(QtCore.Qt.ElideNone)
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.rad_transf_model_tab = QtGui.QWidget()
        self.rad_transf_model_tab.setObjectName(_fromUtf8("rad_transf_model_tab"))
        self.p_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.p_label.setGeometry(QtCore.QRect(20, 130, 71, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.p_label.sizePolicy().hasHeightForWidth())
        self.p_label.setSizePolicy(sizePolicy)
        self.p_label.setObjectName(_fromUtf8("p_label"))
        self.execPath_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.execPath_label.setGeometry(QtCore.QRect(20, 686, 121, 20))
        self.execPath_label.setObjectName(_fromUtf8("execPath_label"))
        self.cpu_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.cpu_label.setGeometry(QtCore.QRect(20, 645, 111, 21))
        self.cpu_label.setObjectName(_fromUtf8("cpu_label"))
        self.nb_cpu = QtGui.QComboBox(self.rad_transf_model_tab)
        self.nb_cpu.setGeometry(QtCore.QRect(160, 640, 71, 31))
        self.nb_cpu.setObjectName(_fromUtf8("nb_cpu"))
        self.sens = QtGui.QSlider(self.rad_transf_model_tab)
        self.sens.setEnabled(True)
        self.sens.setGeometry(QtCore.QRect(630, 370, 721, 31))
        self.sens.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.sens.setFocusPolicy(QtCore.Qt.NoFocus)
        self.sens.setAutoFillBackground(False)
        self.sens.setOrientation(QtCore.Qt.Horizontal)
        self.sens.setObjectName(_fromUtf8("sens"))
        self.label_17 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_17.setGeometry(QtCore.QRect(580, 380, 41, 16))
        self.label_17.setObjectName(_fromUtf8("label_17"))
        self.line = QtGui.QFrame(self.rad_transf_model_tab)
        self.line.setEnabled(True)
        self.line.setGeometry(QtCore.QRect(560, 20, 20, 701))
        self.line.setAutoFillBackground(False)
        self.line.setFrameShape(QtGui.QFrame.VLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.exec_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.exec_path.setEnabled(False)
        self.exec_path.setGeometry(QtCore.QRect(40, 720, 481, 21))
        self.exec_path.setObjectName(_fromUtf8("exec_path"))
        self.p_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.p_values.setGeometry(QtCore.QRect(120, 130, 401, 21))
        self.p_values.setObjectName(_fromUtf8("p_values"))
        self.title_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.title_label.setGeometry(QtCore.QRect(20, 0, 361, 31))
        self.title_label.setObjectName(_fromUtf8("title_label"))
        self.particles_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.particles_label.setGeometry(QtCore.QRect(20, 155, 121, 21))
        self.particles_label.setObjectName(_fromUtf8("particles_label"))
        self.x_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.x_value.setGeometry(QtCore.QRect(120, 180, 401, 21))
        self.x_value.setObjectName(_fromUtf8("x_value"))
        self.y_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.y_value.setGeometry(QtCore.QRect(120, 210, 401, 21))
        self.y_value.setObjectName(_fromUtf8("y_value"))
        self.x_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.x_label.setGeometry(QtCore.QRect(75, 180, 21, 21))
        self.x_label.setObjectName(_fromUtf8("x_label"))
        self.y_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.y_label.setGeometry(QtCore.QRect(75, 210, 21, 21))
        self.y_label.setObjectName(_fromUtf8("y_label"))
        self.organic_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.organic_label.setGeometry(QtCore.QRect(20, 235, 131, 21))
        self.organic_label.setObjectName(_fromUtf8("organic_label"))
        self.s_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.s_value.setGeometry(QtCore.QRect(120, 290, 401, 21))
        self.s_value.setObjectName(_fromUtf8("s_value"))
        self.g_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.g_value.setGeometry(QtCore.QRect(120, 260, 401, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g_value.sizePolicy().hasHeightForWidth())
        self.g_value.setSizePolicy(sizePolicy)
        self.g_value.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.g_value.setObjectName(_fromUtf8("g_value"))
        self.g_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.g_label.setGeometry(QtCore.QRect(73, 260, 21, 21))
        self.g_label.setObjectName(_fromUtf8("g_label"))
        self.s_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.s_label.setGeometry(QtCore.QRect(76, 290, 21, 21))
        self.s_label.setObjectName(_fromUtf8("s_label"))
        self.z_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.z_label.setGeometry(QtCore.QRect(20, 320, 71, 21))
        self.z_label.setObjectName(_fromUtf8("z_label"))
        self.z_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.z_value.setGeometry(QtCore.QRect(120, 320, 401, 21))
        self.z_value.setObjectName(_fromUtf8("z_value"))
        self.label_10 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_10.setGeometry(QtCore.QRect(530, 320, 21, 21))
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.exec_path_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.exec_path_button.setGeometry(QtCore.QRect(160, 680, 71, 31))
        self.exec_path_button.setObjectName(_fromUtf8("exec_path_button"))
        self.waveL_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.waveL_label.setGeometry(QtCore.QRect(20, 350, 101, 21))
        self.waveL_label.setObjectName(_fromUtf8("waveL_label"))
        self.wavelength_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.wavelength_values.setGeometry(QtCore.QRect(120, 350, 401, 21))
        self.wavelength_values.setObjectName(_fromUtf8("wavelength_values"))
        self.phyto_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.phyto_label.setGeometry(QtCore.QRect(20, 475, 191, 21))
        self.phyto_label.setTextFormat(QtCore.Qt.AutoText)
        self.phyto_label.setObjectName(_fromUtf8("phyto_label"))
        self.phyto_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.phyto_button.setGeometry(QtCore.QRect(220, 470, 71, 31))
        self.phyto_button.setObjectName(_fromUtf8("phyto_button"))
        self.phyto_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.phyto_path.setEnabled(False)
        self.phyto_path.setGeometry(QtCore.QRect(30, 510, 491, 21))
        self.phyto_path.setObjectName(_fromUtf8("phyto_path"))
        self.bottom_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.bottom_label.setGeometry(QtCore.QRect(20, 405, 141, 21))
        self.bottom_label.setObjectName(_fromUtf8("bottom_label"))
        self.bottom_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.bottom_path.setEnabled(False)
        self.bottom_path.setGeometry(QtCore.QRect(30, 440, 491, 21))
        self.bottom_path.setObjectName(_fromUtf8("bottom_path"))
        self.bottom_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.bottom_button.setGeometry(QtCore.QRect(220, 400, 71, 31))
        self.bottom_button.setObjectName(_fromUtf8("bottom_button"))
        self.verbose_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.verbose_label.setGeometry(QtCore.QRect(20, 610, 66, 21))
        self.verbose_label.setObjectName(_fromUtf8("verbose_label"))
        self.verbose_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.verbose_value.setGeometry(QtCore.QRect(160, 610, 71, 21))
        self.verbose_value.setObjectName(_fromUtf8("verbose_value"))
        self.label_14 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_14.setGeometry(QtCore.QRect(530, 350, 31, 21))
        self.label_14.setObjectName(_fromUtf8("label_14"))
        self.label_31 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_31.setGeometry(QtCore.QRect(240, 610, 51, 16))
        self.label_31.setObjectName(_fromUtf8("label_31"))
        self.label_32 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_32.setGeometry(QtCore.QRect(240, 650, 131, 16))
        self.label_32.setObjectName(_fromUtf8("label_32"))
        self.graphicsView_3 = QtGui.QGraphicsView(self.rad_transf_model_tab)
        self.graphicsView_3.setGeometry(QtCore.QRect(580, 10, 771, 351))
        self.graphicsView_3.setObjectName(_fromUtf8("graphicsView_3"))
        self.graphic_widget = matplotlibWidget(self.rad_transf_model_tab)
        self.graphic_widget.setGeometry(QtCore.QRect(570, 0, 791, 371))
        self.graphic_widget.setObjectName(_fromUtf8("graphic_widget"))
        self.line_3 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_3.setGeometry(QtCore.QRect(830, 410, 20, 311))
        self.line_3.setFrameShape(QtGui.QFrame.VLine)
        self.line_3.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_3.setObjectName(_fromUtf8("line_3"))
        self.label = QtGui.QLabel(self.rad_transf_model_tab)
        self.label.setGeometry(QtCore.QRect(580, 410, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_2.setGeometry(QtCore.QRect(870, 410, 171, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.column1_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column1_label.setGeometry(QtCore.QRect(890, 440, 131, 21))
        self.column1_label.setText(_fromUtf8(""))
        self.column1_label.setObjectName(_fromUtf8("column1_label"))
        self.column2_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column2_label.setGeometry(QtCore.QRect(890, 470, 131, 21))
        self.column2_label.setText(_fromUtf8(""))
        self.column2_label.setObjectName(_fromUtf8("column2_label"))
        self.column1_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column1_result.setGeometry(QtCore.QRect(1030, 440, 41, 17))
        self.column1_result.setText(_fromUtf8(""))
        self.column1_result.setObjectName(_fromUtf8("column1_result"))
        self.column2_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column2_result.setGeometry(QtCore.QRect(1030, 470, 41, 17))
        self.column2_result.setText(_fromUtf8(""))
        self.column2_result.setObjectName(_fromUtf8("column2_result"))
        self.show_all_curves = QtGui.QCheckBox(self.rad_transf_model_tab)
        self.show_all_curves.setGeometry(QtCore.QRect(600, 440, 131, 22))
        self.show_all_curves.setObjectName(_fromUtf8("show_all_curves"))
        self.column3_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column3_label.setGeometry(QtCore.QRect(890, 500, 131, 16))
        self.column3_label.setText(_fromUtf8(""))
        self.column3_label.setObjectName(_fromUtf8("column3_label"))
        self.column5_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column5_label.setGeometry(QtCore.QRect(890, 560, 131, 16))
        self.column5_label.setText(_fromUtf8(""))
        self.column5_label.setObjectName(_fromUtf8("column5_label"))
        self.column6_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column6_label.setGeometry(QtCore.QRect(890, 590, 131, 16))
        self.column6_label.setText(_fromUtf8(""))
        self.column6_label.setObjectName(_fromUtf8("column6_label"))
        self.column7_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column7_label.setGeometry(QtCore.QRect(890, 620, 131, 16))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.column7_label.setFont(font)
        self.column7_label.setText(_fromUtf8(""))
        self.column7_label.setObjectName(_fromUtf8("column7_label"))
        self.column8_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column8_label.setGeometry(QtCore.QRect(890, 650, 131, 16))
        self.column8_label.setText(_fromUtf8(""))
        self.column8_label.setObjectName(_fromUtf8("column8_label"))
        self.column3_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column3_result.setGeometry(QtCore.QRect(1030, 500, 41, 17))
        self.column3_result.setText(_fromUtf8(""))
        self.column3_result.setObjectName(_fromUtf8("column3_result"))
        self.column4_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column4_result.setGeometry(QtCore.QRect(1030, 530, 41, 17))
        self.column4_result.setText(_fromUtf8(""))
        self.column4_result.setObjectName(_fromUtf8("column4_result"))
        self.column5_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column5_result.setGeometry(QtCore.QRect(1030, 560, 41, 17))
        self.column5_result.setText(_fromUtf8(""))
        self.column5_result.setObjectName(_fromUtf8("column5_result"))
        self.column6_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column6_result.setGeometry(QtCore.QRect(1030, 590, 41, 17))
        self.column6_result.setText(_fromUtf8(""))
        self.column6_result.setObjectName(_fromUtf8("column6_result"))
        self.column7_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column7_result.setGeometry(QtCore.QRect(1030, 620, 41, 17))
        self.column7_result.setText(_fromUtf8(""))
        self.column7_result.setObjectName(_fromUtf8("column7_result"))
        self.column8_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column8_result.setGeometry(QtCore.QRect(1030, 650, 41, 17))
        self.column8_result.setText(_fromUtf8(""))
        self.column8_result.setObjectName(_fromUtf8("column8_result"))
        self.column4_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column4_label.setGeometry(QtCore.QRect(890, 530, 131, 20))
        self.column4_label.setText(_fromUtf8(""))
        self.column4_label.setObjectName(_fromUtf8("column4_label"))
        self.line_4 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_4.setGeometry(QtCore.QRect(60, 380, 421, 21))
        self.line_4.setFrameShape(QtGui.QFrame.HLine)
        self.line_4.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_4.setObjectName(_fromUtf8("line_4"))
        self.line_5 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_5.setGeometry(QtCore.QRect(60, 540, 421, 21))
        self.line_5.setFrameShape(QtGui.QFrame.HLine)
        self.line_5.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_5.setObjectName(_fromUtf8("line_5"))
        self.report_parameter_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.report_parameter_value.setGeometry(QtCore.QRect(160, 570, 121, 21))
        self.report_parameter_value.setObjectName(_fromUtf8("report_parameter_value"))
        self.report_parameter_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.report_parameter_label.setGeometry(QtCore.QRect(20, 570, 131, 21))
        self.report_parameter_label.setObjectName(_fromUtf8("report_parameter_label"))
        self.batch_name_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.batch_name_label.setGeometry(QtCore.QRect(20, 40, 91, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.batch_name_label.sizePolicy().hasHeightForWidth())
        self.batch_name_label.setSizePolicy(sizePolicy)
        self.batch_name_label.setObjectName(_fromUtf8("batch_name_label"))
        self.batch_name_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.batch_name_value.setGeometry(QtCore.QRect(120, 40, 141, 21))
        self.batch_name_value.setObjectName(_fromUtf8("batch_name_value"))
        self.open_result_file_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.open_result_file_button.setGeometry(QtCore.QRect(600, 500, 121, 31))
        self.open_result_file_button.setObjectName(_fromUtf8("open_result_file_button"))
        self.saa_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.saa_values.setGeometry(QtCore.QRect(120, 70, 401, 21))
        self.saa_values.setObjectName(_fromUtf8("saa_values"))
        self.sza_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.sza_values.setGeometry(QtCore.QRect(120, 100, 401, 21))
        self.sza_values.setObjectName(_fromUtf8("sza_values"))
        self.saa_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.saa_label.setGeometry(QtCore.QRect(20, 70, 81, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saa_label.sizePolicy().hasHeightForWidth())
        self.saa_label.setSizePolicy(sizePolicy)
        self.saa_label.setObjectName(_fromUtf8("saa_label"))
        self.sza_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.sza_label.setGeometry(QtCore.QRect(20, 100, 81, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sza_label.sizePolicy().hasHeightForWidth())
        self.sza_label.setSizePolicy(sizePolicy)
        self.sza_label.setObjectName(_fromUtf8("sza_label"))
        self.show_grid = QtGui.QCheckBox(self.rad_transf_model_tab)
        self.show_grid.setGeometry(QtCore.QRect(600, 470, 61, 22))
        self.show_grid.setObjectName(_fromUtf8("show_grid"))
        self.mouse_coordinate = QtGui.QLabel(self.rad_transf_model_tab)
        self.mouse_coordinate.setGeometry(QtCore.QRect(728, 551, 121, 21))
        self.mouse_coordinate.setObjectName(_fromUtf8("mouse_coordinate"))
        self.label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_3.setGeometry(QtCore.QRect(585, 551, 141, 21))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_4.setGeometry(QtCore.QRect(610, 630, 151, 51))
        self.label_4.setText(_fromUtf8(""))
        self.label_4.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/bbp.png")))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_5.setGeometry(QtCore.QRect(610, 700, 211, 21))
        self.label_5.setText(_fromUtf8(""))
        self.label_5.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/CDOM.png")))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.label_6 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_6.setGeometry(QtCore.QRect(586, 600, 161, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.line_6 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_6.setGeometry(QtCore.QRect(605, 576, 201, 20))
        self.line_6.setFrameShape(QtGui.QFrame.HLine)
        self.line_6.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_6.setObjectName(_fromUtf8("line_6"))
        self.label_11 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_11.setGeometry(QtCore.QRect(524, 70, 41, 21))
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.label_13 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_13.setGeometry(QtCore.QRect(524, 100, 41, 21))
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.label_7 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_7.setGeometry(QtCore.QRect(154, 159, 31, 17))
        self.label_7.setText(_fromUtf8(""))
        self.label_7.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/b_bp_small.png")))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.label_8 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_8.setGeometry(QtCore.QRect(160, 241, 31, 17))
        self.label_8.setText(_fromUtf8(""))
        self.label_8.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/ag.png")))
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.sza_values_3 = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.sza_values_3.setGeometry(QtCore.QRect(420, 600, 51, 21))
        self.sza_values_3.setObjectName(_fromUtf8("sza_values_3"))
        self.saa_label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.saa_label_3.setGeometry(QtCore.QRect(310, 570, 101, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saa_label_3.sizePolicy().hasHeightForWidth())
        self.saa_label_3.setSizePolicy(sizePolicy)
        self.saa_label_3.setObjectName(_fromUtf8("saa_label_3"))
        self.saa_values_3 = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.saa_values_3.setGeometry(QtCore.QRect(420, 570, 51, 21))
        self.saa_values_3.setObjectName(_fromUtf8("saa_values_3"))
        self.label_61 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_61.setGeometry(QtCore.QRect(490, 600, 41, 21))
        self.label_61.setObjectName(_fromUtf8("label_61"))
        self.label_62 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_62.setGeometry(QtCore.QRect(490, 570, 41, 21))
        self.label_62.setObjectName(_fromUtf8("label_62"))
        self.sza_label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.sza_label_3.setGeometry(QtCore.QRect(310, 600, 91, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sza_label_3.sizePolicy().hasHeightForWidth())
        self.sza_label_3.setSizePolicy(sizePolicy)
        self.sza_label_3.setObjectName(_fromUtf8("sza_label_3"))
        self.tabWidget.addTab(self.rad_transf_model_tab, _fromUtf8(""))
        self.reverse_tab = QtGui.QWidget()
        self.reverse_tab.setObjectName(_fromUtf8("reverse_tab"))
        self.line_2 = QtGui.QFrame(self.reverse_tab)
        self.line_2.setGeometry(QtCore.QRect(560, 0, 20, 721))
        self.line_2.setFrameShape(QtGui.QFrame.VLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName(_fromUtf8("line_2"))
        self.label_20 = QtGui.QLabel(self.reverse_tab)
        self.label_20.setGeometry(QtCore.QRect(580, 400, 66, 17))
        self.label_20.setObjectName(_fromUtf8("label_20"))
        self.radioButton_2 = QtGui.QRadioButton(self.reverse_tab)
        self.radioButton_2.setGeometry(QtCore.QRect(80, 110, 116, 22))
        self.radioButton_2.setObjectName(_fromUtf8("radioButton_2"))
        self.radioButton_3 = QtGui.QRadioButton(self.reverse_tab)
        self.radioButton_3.setGeometry(QtCore.QRect(80, 140, 116, 22))
        self.radioButton_3.setObjectName(_fromUtf8("radioButton_3"))
        self.label_19 = QtGui.QLabel(self.reverse_tab)
        self.label_19.setGeometry(QtCore.QRect(40, 50, 101, 16))
        self.label_19.setObjectName(_fromUtf8("label_19"))
        self.label_18 = QtGui.QLabel(self.reverse_tab)
        self.label_18.setGeometry(QtCore.QRect(10, 20, 191, 16))
        self.label_18.setObjectName(_fromUtf8("label_18"))
        self.x_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.x_value_reverse.setGeometry(QtCore.QRect(710, 480, 51, 21))
        self.x_value_reverse.setObjectName(_fromUtf8("x_value_reverse"))
        self.label_27 = QtGui.QLabel(self.reverse_tab)
        self.label_27.setGeometry(QtCore.QRect(650, 600, 21, 16))
        self.label_27.setObjectName(_fromUtf8("label_27"))
        self.label_22 = QtGui.QLabel(self.reverse_tab)
        self.label_22.setGeometry(QtCore.QRect(610, 460, 151, 21))
        self.label_22.setObjectName(_fromUtf8("label_22"))
        self.label_29 = QtGui.QLabel(self.reverse_tab)
        self.label_29.setGeometry(QtCore.QRect(770, 630, 21, 16))
        self.label_29.setObjectName(_fromUtf8("label_29"))
        self.label_24 = QtGui.QLabel(self.reverse_tab)
        self.label_24.setGeometry(QtCore.QRect(650, 510, 21, 16))
        self.label_24.setObjectName(_fromUtf8("label_24"))
        self.label_23 = QtGui.QLabel(self.reverse_tab)
        self.label_23.setGeometry(QtCore.QRect(650, 480, 21, 16))
        self.label_23.setObjectName(_fromUtf8("label_23"))
        self.y_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.y_value_reverse.setGeometry(QtCore.QRect(710, 510, 51, 21))
        self.y_value_reverse.setObjectName(_fromUtf8("y_value_reverse"))
        self.label_21 = QtGui.QLabel(self.reverse_tab)
        self.label_21.setGeometry(QtCore.QRect(610, 430, 71, 16))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_21.sizePolicy().hasHeightForWidth())
        self.label_21.setSizePolicy(sizePolicy)
        self.label_21.setObjectName(_fromUtf8("label_21"))
        self.label_30 = QtGui.QLabel(self.reverse_tab)
        self.label_30.setGeometry(QtCore.QRect(610, 660, 101, 16))
        self.label_30.setObjectName(_fromUtf8("label_30"))
        self.label_25 = QtGui.QLabel(self.reverse_tab)
        self.label_25.setGeometry(QtCore.QRect(610, 540, 151, 21))
        self.label_25.setObjectName(_fromUtf8("label_25"))
        self.g_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.g_value_reverse.setGeometry(QtCore.QRect(710, 560, 51, 21))
        self.g_value_reverse.setObjectName(_fromUtf8("g_value_reverse"))
        self.p_values_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.p_values_reverse.setGeometry(QtCore.QRect(710, 430, 311, 21))
        self.p_values_reverse.setObjectName(_fromUtf8("p_values_reverse"))
        self.s_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.s_value_reverse.setGeometry(QtCore.QRect(710, 600, 51, 21))
        self.s_value_reverse.setObjectName(_fromUtf8("s_value_reverse"))
        self.label_28 = QtGui.QLabel(self.reverse_tab)
        self.label_28.setGeometry(QtCore.QRect(610, 630, 71, 16))
        self.label_28.setObjectName(_fromUtf8("label_28"))
        self.wavelength_values_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.wavelength_values_reverse.setGeometry(QtCore.QRect(710, 660, 311, 21))
        self.wavelength_values_reverse.setObjectName(_fromUtf8("wavelength_values_reverse"))
        self.z_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.z_value_reverse.setGeometry(QtCore.QRect(710, 630, 51, 21))
        self.z_value_reverse.setObjectName(_fromUtf8("z_value_reverse"))
        self.label_26 = QtGui.QLabel(self.reverse_tab)
        self.label_26.setGeometry(QtCore.QRect(650, 560, 21, 16))
        self.label_26.setObjectName(_fromUtf8("label_26"))
        self.graphicsView_4 = QtGui.QGraphicsView(self.reverse_tab)
        self.graphicsView_4.setGeometry(QtCore.QRect(580, 10, 791, 351))
        self.graphicsView_4.setObjectName(_fromUtf8("graphicsView_4"))
        self.widget_2 = QtGui.QWidget(self.reverse_tab)
        self.widget_2.setGeometry(QtCore.QRect(570, 0, 811, 371))
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.label_33 = QtGui.QLabel(self.reverse_tab)
        self.label_33.setGeometry(QtCore.QRect(580, 370, 41, 16))
        self.label_33.setObjectName(_fromUtf8("label_33"))
        self.label_15 = QtGui.QLabel(self.reverse_tab)
        self.label_15.setGeometry(QtCore.QRect(1040, 660, 31, 16))
        self.label_15.setObjectName(_fromUtf8("label_15"))
        self.sens_2 = QtGui.QSlider(self.reverse_tab)
        self.sens_2.setEnabled(True)
        self.sens_2.setGeometry(QtCore.QRect(630, 360, 741, 31))
        self.sens_2.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.sens_2.setAutoFillBackground(False)
        self.sens_2.setOrientation(QtCore.Qt.Horizontal)
        self.sens_2.setObjectName(_fromUtf8("sens_2"))
        self.tabWidget.addTab(self.reverse_tab, _fromUtf8(""))
        self.progressBar = QtGui.QProgressBar(self.centralwidget)
        self.progressBar.setGeometry(QtCore.QRect(130, 796, 331, 21))
        self.progressBar.setMouseTracking(False)
        self.progressBar.setProperty("value", 24)
        self.progressBar.setTextVisible(True)
        self.progressBar.setTextDirection(QtGui.QProgressBar.TopToBottom)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.cancel = QtGui.QPushButton(self.centralwidget)
        self.cancel.setGeometry(QtCore.QRect(470, 790, 101, 31))
        self.cancel.setObjectName(_fromUtf8("cancel"))
        self.quit = QtGui.QPushButton(self.centralwidget)
        self.quit.setGeometry(QtCore.QRect(1270, 790, 101, 31))
        self.quit.setObjectName(_fromUtf8("quit"))
        self.error_text_label = QtGui.QLabel(self.centralwidget)
        self.error_text_label.setGeometry(QtCore.QRect(850, 790, 241, 31))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.error_text_label.sizePolicy().hasHeightForWidth())
        self.error_text_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(15)
        font.setBold(True)
        font.setItalic(False)
        font.setUnderline(True)
        font.setWeight(75)
        font.setStrikeOut(False)
        font.setKerning(True)
        self.error_text_label.setFont(font)
        self.error_text_label.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.error_text_label.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.error_text_label.setAcceptDrops(False)
        self.error_text_label.setAccessibleName(_fromUtf8(""))
        self.error_text_label.setAccessibleDescription(_fromUtf8(""))
        self.error_text_label.setAutoFillBackground(False)
        self.error_text_label.setInputMethodHints(QtCore.Qt.ImhNone)
        self.error_text_label.setScaledContents(False)
        self.error_text_label.setWordWrap(False)
        self.error_text_label.setOpenExternalLinks(False)
        self.error_text_label.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse)
        self.error_text_label.setObjectName(_fromUtf8("error_text_label"))
        self.error_label = QtGui.QLabel(self.centralwidget)
        self.error_label.setGeometry(QtCore.QRect(800, 780, 51, 51))
        self.error_label.setText(_fromUtf8(""))
        self.error_label.setPixmap(QtGui.QPixmap(_fromUtf8("../../../.designer/backup/Icons/beCareful.png")))
        self.error_label.setScaledContents(True)
        self.error_label.setObjectName(_fromUtf8("error_label"))
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setEnabled(True)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1362, 25))
        self.menuBar.setDefaultUp(False)
        self.menuBar.setNativeMenuBar(True)
        self.menuBar.setObjectName(_fromUtf8("menuBar"))
        self.menuEssai = QtGui.QMenu(self.menuBar)
        self.menuEssai.setObjectName(_fromUtf8("menuEssai"))
        self.menuFigure = QtGui.QMenu(self.menuBar)
        self.menuFigure.setObjectName(_fromUtf8("menuFigure"))
        self.menuAbout = QtGui.QMenu(self.menuBar)
        self.menuAbout.setObjectName(_fromUtf8("menuAbout"))
        self.menuHelp = QtGui.QMenu(self.menuBar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        MainWindow.setMenuBar(self.menuBar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(26, 26, 26))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(26, 26, 26))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Shadow, brush)
        self.toolBar.setPalette(palette)
        self.toolBar.setAutoFillBackground(True)
        self.toolBar.setMovable(False)
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setFloatable(False)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionDd = QtGui.QAction(MainWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_document-open.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDd.setIcon(icon)
        self.actionDd.setObjectName(_fromUtf8("actionDd"))
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionSave = QtGui.QAction(MainWindow)
        self.actionSave.setObjectName(_fromUtf8("actionSave"))
        self.actionSave_as = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_document-save.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave_as.setIcon(icon1)
        self.actionSave_as.setObjectName(_fromUtf8("actionSave_as"))
        self.actionOpen = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8("../../../.designer/backup/Icons/document-open.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen.setIcon(icon2)
        self.actionOpen.setIconVisibleInMenu(True)
        self.actionOpen.setObjectName(_fromUtf8("actionOpen"))
        self.actionRun = QtGui.QAction(MainWindow)
        self.actionRun.setObjectName(_fromUtf8("actionRun"))
        self.actionLog_file = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_view-refresh.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionLog_file.setIcon(icon3)
        self.actionLog_file.setObjectName(_fromUtf8("actionLog_file"))
        self.actionDocumentation = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_help-contents.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDocumentation.setIcon(icon4)
        self.actionDocumentation.setObjectName(_fromUtf8("actionDocumentation"))
        self.actionThis_GUI = QtGui.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_help-about.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionThis_GUI.setIcon(icon5)
        self.actionThis_GUI.setObjectName(_fromUtf8("actionThis_GUI"))
        self.menuEssai.addAction(self.actionOpen)
        self.menuEssai.addSeparator()
        self.menuEssai.addAction(self.actionRun)
        self.menuEssai.addSeparator()
        self.menuEssai.addAction(self.actionQuit)
        self.menuFigure.addAction(self.actionSave)
        self.menuFigure.addAction(self.actionSave_as)
        self.menuAbout.addAction(self.actionThis_GUI)
        self.menuHelp.addAction(self.actionLog_file)
        self.menuHelp.addAction(self.actionDocumentation)
        self.menuBar.addAction(self.menuEssai.menuAction())
        self.menuBar.addAction(self.menuFigure.menuAction())
        self.menuBar.addAction(self.menuAbout.menuAction())
        self.menuBar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionDd)
        self.toolBar.addAction(self.actionSave_as)
        self.toolBar.addAction(self.actionDocumentation)
        self.toolBar.addAction(self.actionLog_file)
        self.toolBar.addAction(self.actionThis_GUI)
        self.p_label.setBuddy(self.p_values)
        self.execPath_label.setBuddy(self.exec_path_button)
        self.cpu_label.setBuddy(self.nb_cpu)
        self.x_label.setBuddy(self.x_value)
        self.y_label.setBuddy(self.y_value)
        self.g_label.setBuddy(self.g_value)
        self.s_label.setBuddy(self.s_value)
        self.z_label.setBuddy(self.z_value)
        self.waveL_label.setBuddy(self.wavelength_values)
        self.phyto_label.setBuddy(self.phyto_button)
        self.bottom_label.setBuddy(self.bottom_button)
        self.verbose_label.setBuddy(self.verbose_value)
        self.report_parameter_label.setBuddy(self.report_parameter_value)
        self.batch_name_label.setBuddy(self.batch_name_value)
        self.saa_label.setBuddy(self.saa_values)
        self.sza_label.setBuddy(self.sza_values)
        self.saa_label_3.setBuddy(self.saa_values)
        self.sza_label_3.setBuddy(self.sza_values)
        self.label_27.setBuddy(self.s_value_reverse)
        self.label_24.setBuddy(self.y_value_reverse)
        self.label_23.setBuddy(self.x_value_reverse)
        self.label_21.setBuddy(self.p_values_reverse)
        self.label_30.setBuddy(self.wavelength_values_reverse)
        self.label_28.setBuddy(self.z_value_reverse)
        self.label_26.setBuddy(self.g_value_reverse)
        self.label_33.setBuddy(self.sens_2)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.tabWidget, self.batch_name_value)
        MainWindow.setTabOrder(self.batch_name_value, self.saa_values)
        MainWindow.setTabOrder(self.saa_values, self.sza_values)
        MainWindow.setTabOrder(self.sza_values, self.p_values)
        MainWindow.setTabOrder(self.p_values, self.x_value)
        MainWindow.setTabOrder(self.x_value, self.y_value)
        MainWindow.setTabOrder(self.y_value, self.g_value)
        MainWindow.setTabOrder(self.g_value, self.s_value)
        MainWindow.setTabOrder(self.s_value, self.z_value)
        MainWindow.setTabOrder(self.z_value, self.wavelength_values)
        MainWindow.setTabOrder(self.wavelength_values, self.report_parameter_value)
        MainWindow.setTabOrder(self.report_parameter_value, self.verbose_value)
        MainWindow.setTabOrder(self.verbose_value, self.nb_cpu)
        MainWindow.setTabOrder(self.nb_cpu, self.show_all_curves)
        MainWindow.setTabOrder(self.show_all_curves, self.show_grid)
        MainWindow.setTabOrder(self.show_grid, self.bottom_button)
        MainWindow.setTabOrder(self.bottom_button, self.phyto_button)
        MainWindow.setTabOrder(self.phyto_button, self.exec_path_button)
        MainWindow.setTabOrder(self.exec_path_button, self.run)
        MainWindow.setTabOrder(self.run, self.cancel)
        MainWindow.setTabOrder(self.cancel, self.open_result_file_button)
        MainWindow.setTabOrder(self.open_result_file_button, self.quit)
        MainWindow.setTabOrder(self.quit, self.bottom_path)
        MainWindow.setTabOrder(self.bottom_path, self.phyto_path)
        MainWindow.setTabOrder(self.phyto_path, self.exec_path)
        MainWindow.setTabOrder(self.exec_path, self.graphicsView_3)
        MainWindow.setTabOrder(self.graphicsView_3, self.radioButton_3)
        MainWindow.setTabOrder(self.radioButton_3, self.x_value_reverse)
        MainWindow.setTabOrder(self.x_value_reverse, self.y_value_reverse)
        MainWindow.setTabOrder(self.y_value_reverse, self.g_value_reverse)
        MainWindow.setTabOrder(self.g_value_reverse, self.p_values_reverse)
        MainWindow.setTabOrder(self.p_values_reverse, self.s_value_reverse)
        MainWindow.setTabOrder(self.s_value_reverse, self.wavelength_values_reverse)
        MainWindow.setTabOrder(self.wavelength_values_reverse, self.z_value_reverse)
        MainWindow.setTabOrder(self.z_value_reverse, self.graphicsView_4)
        MainWindow.setTabOrder(self.graphicsView_4, self.sens_2)
        MainWindow.setTabOrder(self.sens_2, self.radioButton_2)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "PlanarRad", None))
        self.run.setText(_translate("MainWindow", "Run", None))
        self.p_label.setText(_translate("MainWindow", "P values ", None))
        self.execPath_label.setText(_translate("MainWindow", "Path to Planarrad", None))
        self.cpu_label.setText(_translate("MainWindow", "Number of CPU ", None))
        self.label_17.setText(_translate("MainWindow", "Sens.", None))
        self.exec_path.setText(_translate("MainWindow", "/home/marrabld/Apps/jude2_install/bin", None))
        self.p_values.setText(_translate("MainWindow", "0.1", None))
        self.title_label.setText(_translate("MainWindow", "Set the optical parameters list (comma seperated)", None))
        self.particles_label.setText(_translate("MainWindow", "Particle scattering", None))
        self.x_value.setText(_translate("MainWindow", "0.01", None))
        self.y_value.setText(_translate("MainWindow", "1.0", None))
        self.x_label.setText(_translate("MainWindow", "X :", None))
        self.y_label.setText(_translate("MainWindow", "Y :", None))
        self.organic_label.setText(_translate("MainWindow", "Organic absorption", None))
        self.s_value.setText(_translate("MainWindow", "0.015", None))
        self.g_value.setText(_translate("MainWindow", "0.01", None))
        self.g_label.setText(_translate("MainWindow", "G :", None))
        self.s_label.setText(_translate("MainWindow", "S :", None))
        self.z_label.setText(_translate("MainWindow", "Depth (Z) ", None))
        self.z_value.setText(_translate("MainWindow", "10.0", None))
        self.label_10.setText(_translate("MainWindow", "(m)", None))
        self.exec_path_button.setText(_translate("MainWindow", "DIrectory", None))
        self.waveL_label.setText(_translate("MainWindow", "Wavelengths ", None))
        self.wavelength_values.setText(_translate("MainWindow", "410.0, 430.0, 450.0, 470.0, 490.0, 510.0, 530.0, 550.0, 570.0, 590.0, 610.0, 630.0, 650.0, 670.0, 690.0, 710.0, 730.0", None))
        self.phyto_label.setText(_translate("MainWindow", "Phytoplankton absorption ", None))
        self.phyto_button.setText(_translate("MainWindow", "File", None))
        self.phyto_path.setText(_translate("MainWindow", "/home/marrabld/Projects/planarradpy/inputs/iop_files/a_phi.csv", None))
        self.bottom_label.setText(_translate("MainWindow", "Bottom reflectance ", None))
        self.bottom_path.setText(_translate("MainWindow", "/home/marrabld/Projects/planarradpy/inputs/bottom_files/ger_sand17.txt", None))
        self.bottom_button.setText(_translate("MainWindow", "File", None))
        self.verbose_label.setText(_translate("MainWindow", "Verbose ", None))
        self.label_14.setText(_translate("MainWindow", "(nm)", None))
        self.label_31.setText(_translate("MainWindow", "(1 -> 6)", None))
        self.label_32.setText(_translate("MainWindow", "(-1 means all CPUs)", None))
        self.label.setText(_translate("MainWindow", "Plot tools (options)", None))
        self.label_2.setText(_translate("MainWindow", "<html><head/><body><p>Modelled Parameters</p></body></html>", None))
        self.show_all_curves.setText(_translate("MainWindow", "All curves", None))
        self.report_parameter_value.setText(_translate("MainWindow", "Rrs", None))
        self.report_parameter_label.setText(_translate("MainWindow", "Report parameter ", None))
        self.batch_name_label.setText(_translate("MainWindow", "Batch name ", None))
        self.batch_name_value.setText(_translate("MainWindow", "default", None))
        self.open_result_file_button.setText(_translate("MainWindow", "Open report", None))
        self.saa_values.setText(_translate("MainWindow", "0.0", None))
        self.sza_values.setText(_translate("MainWindow", "0.0", None))
        self.saa_label.setText(_translate("MainWindow", "SAA values ", None))
        self.sza_label.setText(_translate("MainWindow", "SZA values ", None))
        self.show_grid.setText(_translate("MainWindow", "Grid", None))
        self.mouse_coordinate.setText(_translate("MainWindow", "(x, y)", None))
        self.label_3.setText(_translate("MainWindow", "Mouse coordinates :", None))
        self.label_6.setText(_translate("MainWindow", "Bio-optical Models:", None))
        self.label_11.setText(_translate("MainWindow", "(deg)", None))
        self.label_13.setText(_translate("MainWindow", "(deg)", None))
        self.sza_values_3.setText(_translate("MainWindow", "0.0", None))
        self.saa_label_3.setText(_translate("MainWindow", "View Azimuth", None))
        self.saa_values_3.setText(_translate("MainWindow", "0.0", None))
        self.label_61.setText(_translate("MainWindow", "(deg)", None))
        self.label_62.setText(_translate("MainWindow", "(deg)", None))
        self.sza_label_3.setText(_translate("MainWindow", "View Zenith", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.rad_transf_model_tab), _translate("MainWindow", "Radiative Transfer Model", None))
        self.label_20.setText(_translate("MainWindow", "Details :", None))
        self.radioButton_2.setText(_translate("MainWindow", "HOPE (1999)", None))
        self.radioButton_3.setText(_translate("MainWindow", "RadioButton", None))
        self.label_19.setText(_translate("MainWindow", "Tool (method) :", None))
        self.label_18.setText(_translate("MainWindow", "Deconvolution parameters :", None))
        self.label_27.setText(_translate("MainWindow", "s :", None))
        self.label_22.setText(_translate("MainWindow", "Particules scaterring :", None))
        self.label_29.setText(_translate("MainWindow", "(m)", None))
        self.label_24.setText(_translate("MainWindow", "y :", None))
        self.label_23.setText(_translate("MainWindow", "x :", None))
        self.label_21.setText(_translate("MainWindow", "P values :", None))
        self.label_30.setText(_translate("MainWindow", "Wavelengths :", None))
        self.label_25.setText(_translate("MainWindow", "Organic absorption :", None))
        self.label_28.setText(_translate("MainWindow", "Depth (z) :", None))
        self.label_26.setText(_translate("MainWindow", "g :", None))
        self.label_33.setText(_translate("MainWindow", "Sens.", None))
        self.label_15.setText(_translate("MainWindow", "(nm)", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.reverse_tab), _translate("MainWindow", "Inverse", None))
        self.cancel.setText(_translate("MainWindow", "Cancel", None))
        self.quit.setText(_translate("MainWindow", "Quit", None))
        self.error_text_label.setText(_translate("MainWindow", "Check values !", None))
        self.menuEssai.setTitle(_translate("MainWindow", "File", None))
        self.menuFigure.setTitle(_translate("MainWindow", "Figure", None))
        self.menuAbout.setTitle(_translate("MainWindow", "About", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help !", None))
        self.toolBar.setWindowTitle(_translate("MainWindow", "toolBar", None))
        self.actionDd.setText(_translate("MainWindow", "Open", None))
        self.actionQuit.setText(_translate("MainWindow", "Quit", None))
        self.actionSave.setText(_translate("MainWindow", "Save", None))
        self.actionSave_as.setText(_translate("MainWindow", "Save As ...", None))
        self.actionOpen.setText(_translate("MainWindow", "Open", None))
        self.actionRun.setText(_translate("MainWindow", "Run", None))
        self.actionLog_file.setText(_translate("MainWindow", "Log file", None))
        self.actionDocumentation.setText(_translate("MainWindow", "Documentation", None))
        self.actionThis_GUI.setText(_translate("MainWindow", "This GUI !", None))

from gui_matplotlibwidgetFile import matplotlibWidget
import resources_rc
